#######################################################################
#
#    Converter for Enigma2
#    Coded by shamann (c)2016
#
#    This program is free software; you can redistribute it and/or
#    modify it under the terms of the GNU General Public License
#    as published by the Free Software Foundation; either version 2
#    of the License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#    
#######################################################################

from Renderer import Renderer
from enigma import ePixmap
from Tools.Directories import SCOPE_SKIN_IMAGE, SCOPE_CURRENT_SKIN, resolveFilename
from enigma import eServiceReference, eServiceCenter
from Components.config import config
from ServiceReference import ServiceReference
import os, re

class g16RefTV(Renderer):

	def __init__(self):
		Renderer.__init__(self)
		self.pngname = ""
		self.service_center = eServiceCenter.getInstance()
	GUI_WIDGET = ePixmap

	def changed(self, what):
		def fixZero(w):
			if w[0] == "0":
				w = w[1:]		
			return w
		if self.instance:
			pngname = ""
			if what[0] != self.CHANGED_CLEAR:
				service = self.source.service
				marker = (service.flags & eServiceReference.isMarker == eServiceReference.isMarker)
				bouquet = (service.flags & eServiceReference.flagDirectory == eServiceReference.flagDirectory)
				if marker:
					tmp = resolveFilename(SCOPE_CURRENT_SKIN, "marker.png")
					if os.path.isfile(tmp):
						pngname = tmp
					else:
						pngname = resolveFilename(SCOPE_SKIN_IMAGE, "skin_default/picon_default.png")
				else:
					sname = service.toString()
					if sname is not None and sname != "":
						tmp = self.alternative(sname).split(':', 10)[:10]
						if len(tmp) > 0 and tmp[0] == '4097':
							tmp[0] = '1'
						sname = '_'.join(tmp)
						pngname = self.findPicon(sname)
						if pngname == "" and len(sname) > 11:
 							pngname = self.findPicon(sname[:-10]+"0000_0_0_0")
							if pngname == "":
								for i in ("1","19","16"):
									if i != tmp[2]:
										tmp[2] = i
										sname = '_'.join(tmp)
										pngname = self.findPicon(sname[:-10]+"0000_0_0_0")
										if pngname != "":
											break
				if pngname == "":
					if bouquet:
						info = self.service_center.info(service)		
						serviceName = info.getName(service) or ServiceReference(service).getServiceName() or ""
						if serviceName != "":
							tmp = ""
							try:				
								serviceName = ''.join(i for i in serviceName if ord(i)<128)
								serviceName = serviceName.replace("\t","").strip().upper()
								serviceName = serviceName.replace(",","").replace("(","").replace(")","")
							except: pass
							bb = re.search(r"(\d{1,3}[,\.]\d[EW])",serviceName)
							if "DVB-C" in serviceName:
								tmp = "picon_cable"
							elif "DVB-T" in serviceName:
								tmp = "picon_trs"
							elif bb:
								tmp = fixZero((bb.group()).replace(".","").replace(",",""))
							if tmp != "":
								pngname = self.findPicon(tmp, "piconSat")
							if pngname == "":					
								pngname = self.findPicon(serviceName, "piconProv")
								if pngname == "":
									tmp = resolveFilename(SCOPE_CURRENT_SKIN, "bouquet.png")
									if os.path.isfile(tmp):
										pngname = tmp
									else:
										pngname = resolveFilename(SCOPE_SKIN_IMAGE, "skin_default/picon_default.png")
					else:
						pngname = self.findPicon("picon_default")
						if pngname == "":
							tmp = resolveFilename(SCOPE_CURRENT_SKIN, "picon_default.png")
							if os.path.isfile(tmp):
								pngname = tmp
							else:
								pngname = resolveFilename(SCOPE_SKIN_IMAGE, "skin_default/picon_default.png")
				if self.pngname != pngname:
					self.pngname = pngname
					self.instance.setPixmapFromFile(self.pngname)
            		
	def alternative(self, serviceName):
		def alternativeChannels(service):
			tmp = eServiceCenter.getInstance().list(eServiceReference(service))
			return tmp and tmp.getContent("S", True)
		if serviceName.startswith('1:134:'):
			channels = alternativeChannels(serviceName)
			if channels:
				return channels[0]
		return serviceName

	def findPicon(self, serviceName, typ="picon"):
		try:
			pngname = "%s/%s/%s.png" % (config.plugins.setupGlass16.par39.value, typ, serviceName)
			if os.path.isfile(pngname):
				return pngname
		except: pass
		return ""
