#######################################################################
#
#    Renderer for Enigma2
#    Coded by shamann (c)2016
#
#    This program is free software; you can redistribute it and/or
#    modify it under the terms of the GNU General Public License
#    as published by the Free Software Foundation; either version 2
#    of the License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#    
#######################################################################

from Renderer import Renderer
from enigma import eLabel
from Components.VariableText import VariableText
from Components.config import config
from time import localtime, strftime
from Components.Language import language
import os

class g16dateFormat(VariableText, Renderer):

	def __init__(self):
		Renderer.__init__(self)
		VariableText.__init__(self)
		self.format = "%A %B %d, %Y"
		self.fTyp = "0"
		self.readLocaleStrings()
		
	def applySkin(self, desktop, parent):
		attribs = [ ]
		for (attrib, value) in self.skinAttributes:
			if attrib == "format":
				self.format = value
			elif attrib == "fTyp":
				self.fTyp = value
			else:
				attribs.append((attrib,value))
		self.skinAttributes = attribs
		return Renderer.applySkin(self, desktop, parent)

	GUI_WIDGET = eLabel

	def connect(self, source):
		Renderer.connect(self, source)
		self.changed((self.CHANGED_DEFAULT,))
		
	def changed(self, what):
		if self.instance:
			if what[0] != self.CHANGED_CLEAR:
				time = self.source.time
				if time is None:
					self.text = ""
				else:
					f = self.format
					ign = True
					try:				
						if self.fTyp == "1" and config.plugins.setupGlass16.par131.value != "D": 		
							f = config.plugins.setupGlass16.par131.value
						elif self.fTyp == "2" and config.plugins.setupGlass16.par132.value != "D": 		
							f = config.plugins.setupGlass16.par132.value
						elif self.fTyp == "3" and config.plugins.setupGlass16.par133.value != "D": 		
							f = config.plugins.setupGlass16.par133.value
						elif self.fTyp == "4" and config.plugins.setupGlass16.par134.value != "D": 		
							f = config.plugins.setupGlass16.par134.value
						elif config.plugins.setupGlass16.par127.value != "D":			
							f = config.plugins.setupGlass16.par127.value
						if not config.plugins.setupGlass16.par138.value:			
							ign = False
					except: pass
					t = localtime(time)
					spos = f.find('%')
					if spos > 0:
						s1 = f[:spos]
						s2 = strftime(f[spos:], t)
						if ign and f[spos:].startswith("%H") and s2[0] == "0" and s2[1] != ":":
							s2 = s2[1:]
						self.text = self.toLocale(str(s1+s2))
					else:
						s = strftime(f, t)
						if ign and f.startswith("%H") and s[0] == "0" and s[1] != ":": 
							s = s[1:]
						self.text = self.toLocale(s)

	def readLocaleStrings(self):
		self.lcMonths = ["January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"]
		if os.path.isfile('/etc/lcstrings.list') is True:
			myfile = open('/etc/lcstrings.list', 'r')
			lang = language.getActiveLanguage()
			for line in myfile.readlines():
				if line.startswith(str(lang)):
					line = line.strip().split(":")[1]
					self.lcMonths = (line.replace("\t","").replace(" ","")).strip().split(',')
					break
			myfile.close()

	def toLocale(self, s):
		WeekDays = ["Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday", "Sunday"]
		Months = ["January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December"]
		for index, weekday in enumerate(WeekDays): 
			if s.find(weekday) >= 0:
				s = s.replace(weekday, _(weekday))
				break
		for index, month in enumerate(Months): 
			if s.find(month) >= 0:
				s = s.replace(month, self.lcMonths[index])		
				break
		return s
